//  BehaviorPrefsView.swift
//  Tusker
//
//  Created by Shadowfacts on 6/13/19.
//  Copyright © 2019 Shadowfacts. All rights reserved.
//

import SwiftUI
import Pachyderm

struct BehaviorPrefsView : View {
    @Preference(\.defaultPostVisibility) var defaultPostVisibility: Status.Visibility
    @Preference(\.automaticallySaveDrafts) var automaticallySaveDrafts: Bool
    @Preference(\.openLinksInApps) var openLinksInApps: Bool
    
    var body: some View {
        List {
            Section {
                Picker(selection: _defaultPostVisibility.binding, label: Text("Default Post Visibility")) {
                    ForEach(Status.Visibility.allCases, id: \.self) { visibility in
                        HStack {
                            Image(systemName: visibility.imageName)
                            Text(visibility.displayName)
                        }
                            .tag(visibility)
                    }
                }
                Toggle(isOn: _automaticallySaveDrafts.binding) {
                    Text("Automatically Save Drafts")
                }
            }
            Section {
                Toggle(isOn: _openLinksInApps.binding) {
                    Text("Open Links in Apps")
                }
            }
        }
            .listStyle(.grouped)
            .navigationBarTitle(Text("Behavior"))
    }
}

#if DEBUG
struct BehaviorPrefsView_Previews : PreviewProvider {
    static var previews: some View {
        BehaviorPrefsView()
    }
}
#endif
